@@ -2,10 +2,12 @@ import rope.base.builtins
 import rope.base.pynames
 import rope.base.pyobjects
 from rope.base import ast, astutils, exceptions, pyobjects, arguments, worder
+from rope.base.utils import pycompat
 
 
 BadIdentifierError = exceptions.BadIdentifierError
 
+
 def eval_location(pymodule, offset):
     """Find the pyname at the offset"""
     return eval_location2(pymodule, offset)[1]
@@ -40,7 +42,8 @@ def eval_str2(holding_scope, name):
         # parenthesizing for handling cases like 'a_var.\nattr'
         node = ast.parse('(%s)' % name)
     except SyntaxError:
-        raise BadIdentifierError('Not a resolvable python identifier selected.')
+        raise BadIdentifierError(
+            'Not a resolvable python identifier selected.')
     return eval_node2(holding_scope, node)
 
 
@@ -81,7 +84,8 @@ class ScopeNameFinder(object):
             keyword_name = self.worder.get_word_at(offset)
             pyobject = self.get_enclosing_function(offset)
             if isinstance(pyobject, pyobjects.PyFunction):
-                return (None, pyobject.get_parameters().get(keyword_name, None))
+                return (None,
+                        pyobject.get_parameters().get(keyword_name, None))
         # class body
         if self._is_defined_in_class_body(holding_scope, offset, lineno):
             class_scope = holding_scope
@@ -93,11 +97,13 @@ class ScopeNameFinder(object):
             except rope.base.exceptions.AttributeNotFoundError:
                 return (None, None)
         # function header
-        if self._is_function_name_in_function_header(holding_scope, offset, lineno):
+        if self._is_function_name_in_function_header(holding_scope,
+                                                     offset, lineno):
             name = self.worder.get_primary_at(offset).strip()
             return (None, holding_scope.parent[name])
-        # from statement module
-        if self.worder.is_from_statement_module(offset):
+        # module in a from statement or an imported name that is aliased
+        if (self.worder.is_from_statement_module(offset) or
+            self.worder.is_import_statement_aliased_module(offset)):
             module = self.worder.get_primary_at(offset)
             module_pyname = self._find_module(module)
             return (None, module_pyname)
@@ -118,7 +124,7 @@ class ScopeNameFinder(object):
             if isinstance(pyobject, pyobjects.AbstractFunction):
                 return pyobject
             elif isinstance(pyobject, pyobjects.AbstractClass) and \
-                 '__init__' in pyobject:
+                    '__init__' in pyobject:
                 return pyobject['__init__'].get_object()
             elif '__call__' in pyobject:
                 return pyobject['__call__'].get_object()
@@ -157,6 +163,7 @@ class StatementEvaluator(object):
         primary, pyobject = self._get_primary_and_object_for_node(node.func)
         if pyobject is None:
             return
+
         def _get_returned(pyobject):
             args = arguments.create_arguments(primary, pyobject,
                                               node, self.scope)
@@ -189,6 +196,14 @@ class StatementEvaluator(object):
         type_name = type(node.n).__name__
         self.result = self._get_builtin_name(type_name)
 
+    def _Constant(self, node):
+        type_name = type(node.n).__name__
+        try:
+            self.result = self._get_builtin_name(type_name)
+        except exceptions.AttributeNotFoundError:
+            # XXX: Right way to fix this is to add missing NoneType to builtins?
+            pass
+
     def _get_builtin_name(self, type_name):
         pytype = rope.base.builtins.builtins[type_name].get_object()
         return rope.base.pynames.UnboundName(
@@ -285,7 +300,7 @@ class StatementEvaluator(object):
             self._call_function(node.value, '__getitem__',
                                 [node.slice.value])
         elif isinstance(node.slice, ast.Slice):
-            self._call_function(node.value, '__getitem__', 
+            self._call_function(node.value, '__getitem__',
                                 [node.slice])
 
     def _Slice(self, node):
@@ -299,7 +314,8 @@ class StatementEvaluator(object):
             return
         if function_name in pyobject:
             called = pyobject[function_name].get_object()
-            if not called or not isinstance(called, pyobjects.AbstractFunction):
+            if not called or \
+                    not isinstance(called, pyobjects.AbstractFunction):
                 return
             args = [node]
             if other_args:
